@@ -1,4 +1,4 @@
-__version__ = '0.1.7'
+__version__ = '0.1.8'
 
 ## Import packages
 import numpy as np
@@ -61,11 +61,11 @@ def find_vm_sd(channel_responses,stim_max=180,plotting=False):
     yReal = f(np.arange(0,len(channel_responses)-1,(len(channel_responses)-1)/stim_max))
     yReal = np.roll(yReal,stim_max-np.argmax(yReal))
     
-    losses = [np.abs(np.sum(yReal - make_gaussian_iter(180,sd,stim_max))) for sd in np.arange(10,180)]
+    losses = [np.abs(np.sum(yReal - make_gaussian_iter(stim_max//2,sd,stim_max))) for sd in np.arange(10,180)]
 
     if plotting:
         plt.plot(yReal)
-        plt.plot(make_gaussian_iter(180,np.arange(10,180)[np.argmin(losses)],stim_max))
+        plt.plot(make_gaussian_iter(stim_max//2,np.arange(10,180)[np.argmin(losses)],stim_max))
         
     return np.arange(10,180)[np.argmin(losses)]
 def rotate(l,dist):
